@@ -47,7 +47,7 @@ class Test_MSSSideViewWindow(object):
         self.application = QtWidgets.QApplication(sys.argv)
 
         self.window = mss_pyui.MSSMainWindow()
-        self.window.createNewFlightTrack(activate=True)
+        self.window.create_new_flight_track()
         self.window.show()
         QtWidgets.QApplication.processEvents()
         QtTest.QTest.qWaitForWindowExposed(self.window)
@@ -115,14 +115,6 @@ class Test_MSSSideViewWindow(object):
         assert mockbox.critical.call_count == 0
         assert self.window.listTools.count() == 1
 
-    @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
-    def test_open_loopview_tool(self, mockbox):
-        assert self.window.listTools.count() == 0
-        self.window.actionLoopView.trigger()
-        QtWidgets.QApplication.processEvents()
-        assert mockbox.critical.call_count == 0
-        assert self.window.listTools.count() == 1
-
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_open_about(self, mockbox):
         self.window.actionAboutMSUI.trigger()
@@ -163,6 +155,12 @@ class Test_MSSSideViewWindow(object):
         assert mockcrit.call_count == 0
         assert os.path.exists(self.save_ftml)
         os.remove(self.save_ftml)
+        flighttrack = self.window.listFlightTracks.visualItemRect(
+            self.window.listFlightTracks.item(1))
+        QtTest.QTest.mouseClick(
+            self.window.listFlightTracks.viewport(),
+            QtCore.Qt.LeftButton, QtCore.Qt.NoModifier, flighttrack.center())
+        QtWidgets.QApplication.processEvents()
         self.window.actionCloseSelectedFlightTrack.trigger()
         assert self.window.listFlightTracks.count() == 2
         assert mockopen.call_count == 1
@@ -177,11 +175,11 @@ class Test_MSSSideViewWindow(object):
             QtCore.Qt.LeftButton, QtCore.Qt.NoModifier, flighttrack.center())
         QtWidgets.QApplication.processEvents()
         self.window.actionCloseSelectedFlightTrack.trigger()
-        assert self.window.listFlightTracks.count() == 1
         assert mockopen.call_count == 1
         assert mocksave.call_count == 1
         assert mockcrit.call_count == 0
         assert mockinfo.call_count == 1
+        assert self.window.listFlightTracks.count() == 1
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QFileDialog.getOpenFileName",
                 return_value=os.path.join(sample_path, "example.csv"))
@@ -212,8 +210,8 @@ class Test_MSSSideViewWindow(object):
                 return_value=save_txt)
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_plugin_txt(self, mockbox, mocksave, mockopen):
-        self.window.addImportFilter("_TXT", "txt", load_from_txt)
-        self.window.addExportFilter("_TXT", "txt", save_to_txt)
+        self.window.add_import_filter("_TXT", "txt", load_from_txt)
+        self.window.add_export_filter("_TXT", "txt", save_to_txt)
 
         assert self.window.listFlightTracks.count() == 1
         self.window.actionImportFlightTrack_TXT()
@@ -236,7 +234,7 @@ class Test_MSSSideViewWindow(object):
                 return_value=os.path.join(sample_path, "flitestar.txt"))
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_plugin_flitestar(self, mockbox, mockopen):
-        self.window.addImportFilter("_FliteStar", "txt", load_from_flitestar)
+        self.window.add_import_filter("_FliteStar", "txt", load_from_flitestar)
         assert self.window.listFlightTracks.count() == 1
         self.window.actionImportFlightTrack_FliteStar()
         QtWidgets.QApplication.processEvents()
