@@ -31,8 +31,6 @@ from __future__ import division
 # Parts of the code have been adapted from Chapter 6 of Sandro Tosi,
 # 'Matplotlib for Python Developers'.
 
-
-from past.builtins import basestring
 from datetime import datetime
 
 import logging
@@ -98,17 +96,17 @@ class MplCanvas(FigureCanvas):
             result = result[:100]
         return result + ".png"
 
-    def drawMetadata(self, title="", init_time=None, valid_time=None,
-                     level=None, style=None):
+    def draw_metadata(self, title="", init_time=None, valid_time=None,
+                      level=None, style=None):
         """Draw a title indicating the init and valid time of the
            image that has been drawn, and the vertical elevation level.
         """
         self.default_filename = ""
         if title:
             self.default_filename += u"_{:>5}".format(title.split()[0])
-        if isinstance(style, basestring) and style:
+        if style:
             title += u' ({})'.format(style)
-        if isinstance(level, basestring):
+        if level:
             title += u' at {}'.format(level)
             self.default_filename += u"_{}".format(level.split()[0])
         if isinstance(valid_time, datetime) and isinstance(init_time, datetime):
@@ -137,7 +135,7 @@ class MplCanvas(FigureCanvas):
         # without the repaint the title is not properly updated
         self.repaint()
 
-    def getPlotSizePx(self):
+    def get_plot_size_in_px(self):
         """Determines the size of the current figure in pixels.
 
         Returns the tuple width, height.
@@ -213,6 +211,7 @@ class MplSideViewCanvas(MplCanvas):
 
         # Default settings.
         self.settings_dict = {"vertical_extent": (1050, 180),
+                              "vertical_axis": "pressure",
                               "flightlevels": [],
                               "draw_flightlevels": True,
                               "draw_flighttrack": True,
@@ -228,22 +227,22 @@ class MplSideViewCanvas(MplCanvas):
         self.p_bot = self.settings_dict["vertical_extent"][0] * 100
         self.p_top = self.settings_dict["vertical_extent"][1] * 100
         self.numlabels = numlabels
-        self.setupSideView()
+        self.setup_side_view()
         # Draw a number of flight level lines.
         self.flightlevels = []
         self.fl_label_list = []
-        self.drawFlightLevels()
+        self.draw_flight_levels()
         self.imgax = None
         self.image = None
         # If a waypoints model has been passed, create an interactor on it.
         self.waypoints_interactor = None
         self.basename = "sideview"
         if model:
-            self.setWaypointsModel(model)
+            self.set_waypoints_model(model)
 
-        self.setSettings(self.settings_dict)
+        self.set_settings(self.settings_dict)
 
-    def setWaypointsModel(self, model):
+    def set_waypoints_model(self, model):
         """Set the WaypointsTableModel defining the vertical section.
         If no model had been set before, create a new interactor object on the
         model to let the user interactively move the altitude of the waypoints.
@@ -261,7 +260,67 @@ class MplSideViewCanvas(MplCanvas):
                 redraw_xaxis=self.redraw_xaxis, clear_figure=self.clear_figure
             )
 
-    def setupSideView(self):
+    def redraw_yaxis(self):
+        vaxis = self.settings_dict["vertical_axis"]
+        if vaxis == "pressure":
+            # Compute the position of major and minor ticks. Major ticks are labelled.
+            # By default, major ticks are drawn every 100hPa. If p_top < 100hPa,
+            # the distance is reduced to every 10hPa above 100hPa.
+            label_distance = 10000
+            label_bot = self.p_bot - (self.p_bot % label_distance)
+            major_ticks = np.arange(label_bot, self.p_top - 1, -label_distance)
+
+            # .. check step reduction to 10 hPa ..
+            if self.p_top < 10000:
+                major_ticks2 = np.arange(major_ticks[-1], self.p_top - 1, -label_distance // 10)
+                len_major_ticks = len(major_ticks)
+                major_ticks = np.resize(major_ticks,
+                                        len_major_ticks + len(major_ticks2) - 1)
+                major_ticks[len_major_ticks:] = major_ticks2[1:]
+
+            labels = ["{:d}".format(int(l / 100.)) for l in major_ticks]
+
+            # .. the same for the minor ticks ..
+            p_top_minor = max(label_distance, self.p_top)
+            label_distance_minor = 1000
+            label_bot_minor = self.p_bot - (self.p_bot % label_distance_minor)
+            minor_ticks = np.arange(label_bot_minor, p_top_minor - 1,
+                                    -label_distance_minor)
+
+            if self.p_top < 10000:
+                minor_ticks2 = np.arange(minor_ticks[-1], self.p_top - 1, -label_distance_minor // 10)
+                len_minor_ticks = len(minor_ticks)
+                minor_ticks = np.resize(minor_ticks,
+                                        len_minor_ticks + len(minor_ticks2) - 1)
+                minor_ticks[len_minor_ticks:] = minor_ticks2[1:]
+            self.ax.set_ylabel("pressure (hPa)")
+        elif vaxis == "pressure altitude":
+            major_heights = np.arange(0, 30, 2)
+            minor_heights = np.arange(0, 30, 0.25)
+            major_fl = 10 * major_heights / 0.3048
+            minor_fl = 10 * minor_heights / 0.3048
+            major_ticks = thermolib.flightlevel2pressure_a(major_fl)
+            minor_ticks = thermolib.flightlevel2pressure_a(minor_fl)
+            labels = major_heights
+            self.ax.set_ylabel("pressure altitude (km)")
+        elif vaxis == "flight level":
+            major_fl = np.arange(0, 1000, 50)
+            minor_fl = np.arange(0, 1000, 10)
+            major_ticks = thermolib.flightlevel2pressure_a(major_fl)
+            minor_ticks = thermolib.flightlevel2pressure_a(minor_fl)
+            labels = major_fl
+            self.ax.set_ylabel("flight level (hft)")
+        else:
+            raise RuntimeError("Unsupported vertical axis type: '{}'".format(vaxis))
+
+        # Draw ticks and tick labels.
+        self.ax.set_yticks(minor_ticks, minor=True)
+        self.ax.set_yticks(major_ticks, minor=False)
+        self.ax.set_yticklabels([], minor=True, fontsize=10)
+        self.ax.set_yticklabels(labels, minor=False, fontsize=10)
+        self.ax.set_ylim(self.p_bot, self.p_top)
+
+    def setup_side_view(self):
         """Set up a vertical section view.
 
         Vertical cross section code (log-p axis etc.) taken from
@@ -274,54 +333,14 @@ class MplSideViewCanvas(MplCanvas):
         ax.set_title("vertical flight profile", horizontalalignment="left", x=0)
         ax.set_xlim(0, 10)
 
-        p_bot = self.p_bot
-        p_top = self.p_top
-
         ax.set_yscale("log")
 
-        # Compute the position of major and minor ticks. Major ticks are labelled.
-        # By default, major ticks are drawn every 100hPa. If p_top < 100hPa,
-        # the distance is reduced to every 10hPa above 100hPa.
-        label_distance = 10000
-        label_bot = p_bot - (p_bot % label_distance)
-        major_ticks = np.arange(label_bot, p_top - 1, -label_distance)
-
-        # .. check step reduction to 10 hPa ..
-        if p_top < 10000:
-            major_ticks2 = np.arange(major_ticks[-1], p_top - 1, -label_distance // 10)
-            len_major_ticks = len(major_ticks)
-            major_ticks = np.resize(major_ticks,
-                                    len_major_ticks + len(major_ticks2) - 1)
-            major_ticks[len_major_ticks:] = major_ticks2[1:]
-
-        labels = ["{:d}".format(int(l / 100.)) for l in major_ticks]
-
-        # .. the same for the minor ticks ..
-        p_top_minor = max(label_distance, p_top)
-        label_distance_minor = 1000
-        label_bot_minor = p_bot - (p_bot % label_distance_minor)
-        minor_ticks = np.arange(label_bot_minor, p_top_minor - 1,
-                                -label_distance_minor)
-
-        if p_top < 10000:
-            minor_ticks2 = np.arange(minor_ticks[-1], p_top - 1, -label_distance_minor // 10)
-            len_minor_ticks = len(minor_ticks)
-            minor_ticks = np.resize(minor_ticks,
-                                    len_minor_ticks + len(minor_ticks2) - 1)
-            minor_ticks[len_minor_ticks:] = minor_ticks2[1:]
-
-        # Draw ticks and tick labels.
-        ax.set_yticks(minor_ticks, minor=True)
-        ax.set_yticks(major_ticks, minor=False)
-        ax.set_yticklabels([], minor=True, fontsize=10)
-        ax.set_yticklabels(labels, minor=False, fontsize=10)
-
         # Set axis limits and draw grid for major ticks.
-        ax.set_ylim(p_bot, p_top)
+        ax.set_ylim(self.p_bot, self.p_top)
         ax.grid(b=True)
 
         ax.set_xlabel("lat/lon")
-        ax.set_ylabel("pressure (hPa)")
+        self.redraw_yaxis()
 
     def clear_figure(self):
         logging.debug("path of side view has changed.. removing invalidated "
@@ -330,6 +349,7 @@ class MplSideViewCanvas(MplCanvas):
             self.image.remove()
             self.image = None
             self.ax.set_title("vertical flight profile", horizontalalignment="left", x=0)
+            self.ax.figure.canvas.draw()
 
     def redraw_xaxis(self, lats, lons, times):
         """Redraw the x-axis of the side view on path changes. Also remove
@@ -358,7 +378,7 @@ class MplSideViewCanvas(MplCanvas):
                                     rotation=25, fontsize=10, horizontalalignment="right")
         self.draw()
 
-    def setVerticalExtent(self, pbot, ptop):
+    def set_vertical_extent(self, pbot, ptop):
         """Set the vertical extent of the view to the specified pressure
            values (hPa) and redraw the plot.
         """
@@ -373,15 +393,17 @@ class MplSideViewCanvas(MplCanvas):
             if self.image is not None:
                 self.image.remove()
                 self.image = None
-            self.setupSideView()
+            self.setup_side_view()
             self.waypoints_interactor.redraw_figure()
+        else:
+            self.redraw_yaxis()
 
-    def getVerticalExtent(self):
+    def get_vertical_extent(self):
         """Returns the bottom and top pressure (hPa) of the plot.
         """
         return (self.p_bot // 100), (self.p_top // 100)
 
-    def drawFlightLevels(self):
+    def draw_flight_levels(self):
         """Draw horizontal lines indicating the altitude of the flight levels.
         """
         # Remove currently displayed flight level artists.
@@ -396,39 +418,39 @@ class MplSideViewCanvas(MplCanvas):
             self.fl_label_list.append(ax.text(0.1, pressure, u"FL{:d}".format(level)))
         self.draw()
 
-    def getFlightLevels(self):
+    def get_flight_levels(self):
         """
         """
         return self.flightlevels
 
-    def setFlightLevels(self, flightlevels):
+    def set_flight_levels(self, flightlevels):
         """
         """
         self.flightlevels = flightlevels
-        self.drawFlightLevels()
+        self.draw_flight_levels()
 
-    def setFlightLevelsVisible(self, visible):
+    def set_flight_levels_visible(self, visible):
         """Toggle the visibility of the flight level lines.
         """
         for gxelement in self.fl_label_list:
             gxelement.set_visible(visible)
         self.draw()
 
-    def getSettings(self):
+    def get_settings(self):
         """Returns a dictionary containing settings regarding the side view
            appearance.
         """
         return self.settings_dict
 
-    def setSettings(self, settings):
+    def set_settings(self, settings):
         """Apply settings to view.
         """
         if settings is not None:
             self.settings_dict.update(settings)
         settings = self.settings_dict
-        self.setFlightLevels(settings["flightlevels"])
-        self.setVerticalExtent(*settings["vertical_extent"])
-        self.setFlightLevelsVisible(settings["draw_flightlevels"])
+        self.set_flight_levels(settings["flightlevels"])
+        self.set_vertical_extent(*settings["vertical_extent"])
+        self.set_flight_levels_visible(settings["draw_flightlevels"])
         if self.waypoints_interactor is not None:
             self.waypoints_interactor.set_vertices_visible(
                 settings["draw_flighttrack"])
@@ -465,12 +487,12 @@ class MplSideViewCanvas(MplCanvas):
                 num_labels, (axis[3] // 100))
         return bbox
 
-    def drawLegend(self, img):
+    def draw_legend(self, img):
         if img is not None:
             logging.error("Legends not supported in SideView mode!")
             raise NotImplementedError
 
-    def drawImage(self, img):
+    def draw_image(self, img):
         """Draw the image img on the current plot.
 
         NOTE: The image is plotted in a separate axes object that is located
@@ -551,17 +573,17 @@ class MplTopViewCanvas(MplCanvas):
 
         # Set map appearance from parameter or, if not specified, to default
         # values.
-        self.setMapAppearance(settings)
+        self.set_map_appearance(settings)
 
         # Progress dialog to inform the user about map redraws.
         self.pdlg = QtWidgets.QProgressDialog("redrawing map...", "Cancel", 0, 10, self)
         self.pdlg.close()
 
-    def initMap(self, model=None, **kwargs):
+    def init_map(self, model=None, **kwargs):
         """Set up the map view.
         """
         ax = self.ax
-        self.map = mpl_map.MapCanvas(appearance=self.getMapAppearance(),
+        self.map = mpl_map.MapCanvas(appearance=self.get_map_appearance(),
                                      resolution="l", area_thresh=1000., ax=ax,
                                      **kwargs)
         ax.set_autoscale_on(False)
@@ -569,9 +591,9 @@ class MplTopViewCanvas(MplCanvas):
         self.draw()  # necessary?
 
         if model:
-            self.setWaypointsModel(model)
+            self.set_waypoints_model(model)
 
-    def setWaypointsModel(self, model):
+    def set_waypoints_model(self, model):
         """Set the WaypointsTableModel defining the flight track.
         If no model had been set before, create a new interactor object on the
         model to let the user interactively move the altitude of the waypoints.
@@ -582,19 +604,19 @@ class MplTopViewCanvas(MplCanvas):
         else:
             # Create a path interactor object. The interactor object connects
             # itself to the change() signals of the flight track data model.
-            appearance = self.getMapAppearance()
+            appearance = self.get_map_appearance()
             self.waypoints_interactor = mpl_pi.HPathInteractor(
                 self.map, self.waypoints_model,
                 linecolor=appearance["colour_ft_vertices"],
                 markerfacecolor=appearance["colour_ft_waypoints"])
             self.waypoints_interactor.set_vertices_visible(appearance["draw_flighttrack"])
 
-    def setTrajectoryModel(self, model):
+    def set_trajectory_model(self, model):
         """
         """
         self.map.set_trajectory_tree(model)
 
-    def redrawMap(self, kwargs_update=None):
+    def redraw_map(self, kwargs_update=None):
         """Redraw map canvas.
 
         Executed on clicked() of btMapRedraw.
@@ -604,7 +626,7 @@ class MplTopViewCanvas(MplCanvas):
         """
 
         # remove legend
-        self.drawLegend(None)
+        self.draw_legend(None)
 
         # Show the progress dialog, since the retrieval can take a few seconds.
         self.pdlg.setValue(0)
@@ -638,7 +660,7 @@ class MplTopViewCanvas(MplCanvas):
         if self.kmloverlay:
             self.kmloverlay.update()
 
-        self.drawMetadata("Top view")
+        self.draw_metadata("Top view")
 
         # Update in case of a projection change
         self.waypoints_interactor.update()
@@ -652,7 +674,7 @@ class MplTopViewCanvas(MplCanvas):
         # Emit signal so other parts of the module can react to a redraw event.
         self.redrawn.emit()
 
-    def getCRS(self):
+    def get_crs(self):
         """Get the coordinate reference system of the displayed map.
         """
         return self.map.crs
@@ -674,7 +696,15 @@ class MplTopViewCanvas(MplCanvas):
         bbox = (axis[0], axis[2], axis[1], axis[3])
         return bbox
 
-    def drawImage(self, img):
+    def clear_figure(self):
+        logging.debug("Removing image")
+        if self.map.image is not None:
+            self.map.image.remove()
+            self.map.image = None
+            self.ax.set_title("Top view", horizontalalignment="left", x=0)
+            self.ax.figure.canvas.draw()
+
+    def draw_image(self, img):
         """Draw the image img on the current plot.
         """
         logging.debug("plotting image..")
@@ -692,7 +722,7 @@ class MplTopViewCanvas(MplCanvas):
         # ** UPDATE 2011/01/14 ** seems to work with version 1.0!
         logging.debug("done.")
 
-    def drawLegend(self, img):
+    def draw_legend(self, img):
         """Draw the legend graphics img on the current plot.
 
         Adds new axes to the plot that accomodate the legend.
@@ -733,7 +763,7 @@ class MplTopViewCanvas(MplCanvas):
         # required so that it is actually drawn...
         QtWidgets.QApplication.processEvents()
 
-    def plotSatelliteOverpass(self, segment):
+    def plot_satellite_overpass(self, segment):
         """Plots a satellite track on top of the map.
         """
         if self.satoverpasspatch:
@@ -746,7 +776,7 @@ class MplTopViewCanvas(MplCanvas):
             # Create a new patch.
             self.satoverpasspatch = mpl_map.SatelliteOverpassPatch(self.map, segment)
 
-    def plotKML(self, kmloverlay):
+    def plot_kml(self, kmloverlay):
         """Plots a satellite track on top of the map.
         """
         if self.kmloverlay:
@@ -759,7 +789,7 @@ class MplTopViewCanvas(MplCanvas):
             # Create a new patch.
             self.kmloverlay = kmloverlay
 
-    def setMapAppearance(self, settings_dict):
+    def set_map_appearance(self, settings_dict):
         """Apply settings from dictionary 'settings_dict' to the view.
 
         If settings is None, apply default settings.
@@ -793,14 +823,14 @@ class MplTopViewCanvas(MplCanvas):
             self.waypoints_interactor.set_vertices_visible(settings["draw_flighttrack"])
             self.waypoints_interactor.set_labels_visible(settings["label_flighttrack"])
 
-    def setRemoteSensingAppearance(self, settings):
+    def set_remote_sensing_appearance(self, settings):
         self.waypoints_interactor.set_remote_sensing(settings["reference"])
         self.waypoints_interactor.set_tangent_visible(settings["draw_tangents"])
         self.waypoints_interactor.set_solar_angle_visible(settings["show_solar_angle"])
 
         self.waypoints_interactor.redraw_path()
 
-    def getMapAppearance(self):
+    def get_map_appearance(self):
         """
         """
         return self.appearance_settings
@@ -831,13 +861,13 @@ class MplTopViewWidget(MplNavBarWidget):
            Redraws the map after the user has zoomed or panned the image.
         """
         if self.navbar.mode in ["zoom rect", "pan/zoom"]:
-            self.canvas.redrawMap()
+            self.canvas.redraw_map()
 
     def historyEvent(self):
         """Slot to react to clicks on one of the history buttons in the
            navigation toolbar. Redraws the image.
         """
-        self.canvas.redrawMap()
+        self.canvas.redraw_map()
 
 
 class MplTimeSeriesViewCanvas(MplCanvas):
