@@ -1810,9 +1810,10 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None, add_conto
     class fnord(HS_MSSChemStyle):
         name = "HS_" + entity + "_" + vert + _contourname
         dataname = entity
+        units, unit_scale = Targets.get_unit(dataname)
         units = units
         unit_scale = scale
-        _title_tpl = nam + " ({modelname}, " + vert + ")"
+        _title_tpl = nam + " (" + vert + ")"
         long_name = entity
         if units:
             _title_tpl += u" ({})".format(units)
@@ -1820,7 +1821,7 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None, add_conto
         required_datafields = [(vert, entity)] + add_data
         contours = add_contours
 
-    fnord.__name__ = name
+    fnord.__name__ = nam
     fnord.styles = list(fnord.styles)
 
     return fnord
